@@ -19,7 +19,7 @@ from plotnine import *
 import matplotlib.pyplot as plt
 from scipy.stats import hypergeom
 from collections import defaultdict
-from enrRiceTrait.src.enrRiceTrait.PTE_config import db_config
+from PTE_config import db_config
 
 # todo: conver all "concept" and "term" to "trait"
 # todo: Enricher initialize
